package org.jk.system.mapper;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import org.jk.common.mybatis.core.mapper.BaseMapperPlus;
import org.jk.common.mybatis.core.page.PageQuery;
import org.jk.system.domain.SysProject;
import org.jk.system.domain.vo.SysProjectExportVo;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author takai
 * @date 2025-05-28
 */
public interface SysProjectMapper extends BaseMapperPlus<SysProject,SysProject>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param projectId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SysProject selectSysProjectByProjectId(String projectId);

    /**
     * 查询【请填写功能名称】
     *
     * @param projectPid 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SysProject selectSysProjectByProjectPid(String projectPid);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysProject 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SysProject> selectSysProjectList(SysProject sysProject);


    List<SysProjectExportVo> selectSysProjectExcelList(SysProject sysProject);
    /**
     * 新增【请填写功能名称】
     *
     * @param sysProject 【请填写功能名称】
     * @return 结果
     */
    public int insertSysProject(SysProject sysProject);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysProject 【请填写功能名称】
     * @return 结果
     */
    public int updateSysProject(SysProject sysProject);

    /**
     * 删除【请填写功能名称】
     *
     * @param projectId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSysProjectByProjectId(String projectId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysProjectByProjectIds(String[] projectIds);

    public Page<SysProject> selectPageList(@Param("ew") SysProject sysProject,@Param("page") Page pageQuery);
}
